==> plugin.video.tvvlaanderen-1.0.4.zip: plugin.video.tvvlaanderen/CHANGELOG.md <==
# Changelog

## [v1.0.4](https://github.com/add-ons/plugin.video.tvvlaanderen/tree/v1.0.4) (2021-06-25)

[Full Changelog](https://github.com/add-ons/plugin.video.tvvlaanderen/compare/v1.0.3...v1.0.4)

**Fixed bugs:**

- Set a user-agent [\#34](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/34) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.0.3](https://github.com/add-ons/plugin.video.tvvlaanderen/tree/v1.0.3) (2021-02-04)

[Full Changelog](https://github.com/add-ons/plugin.video.tvvlaanderen/compare/v1.0.2...v1.0.3)

**Implemented enhancements:**

- Add http proxy support [\#30](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/30) ([michaelarnauts](https://github.com/michaelarnauts))

**Merged pull requests:**

- Make use of git archive [\#32](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/32) ([dagwieers](https://github.com/dagwieers))
- Improve tests [\#31](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/31) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.0.2](https://github.com/add-ons/plugin.video.tvvlaanderen/tree/v1.0.2) (2020-12-21)

[Full Changelog](https://github.com/add-ons/plugin.video.tvvlaanderen/compare/v1.0.1...v1.0.2)

**Fixed bugs:**

- Don't show the password in the debug log [\#29](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/29) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.0.1](https://github.com/add-ons/plugin.video.tvvlaanderen/tree/v1.0.1) (2020-12-17)

[Full Changelog](https://github.com/add-ons/plugin.video.tvvlaanderen/compare/v1.0.0...v1.0.1)

**Fixed bugs:**

- Fix EPG on windows [\#28](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/28) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.0.0](https://github.com/add-ons/plugin.video.tvvlaanderen/tree/v1.0.0) (2020-12-05)

[Full Changelog](https://github.com/add-ons/plugin.video.tvvlaanderen/compare/v0.0.1...v1.0.0)

**Implemented enhancements:**

- Add PIN protection to 18+ channels [\#26](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/26) ([michaelarnauts](https://github.com/michaelarnauts))
- Add EPG to channel listing [\#24](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/24) ([michaelarnauts](https://github.com/michaelarnauts))
- Improve authentication flow [\#23](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/23) ([michaelarnauts](https://github.com/michaelarnauts))

**Fixed bugs:**

- Fix EPG in the channels view [\#25](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/25) ([michaelarnauts](https://github.com/michaelarnauts))
- Depend on inputstreamhelper to make sure widevine is installed [\#20](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/20) ([mediaminister](https://github.com/mediaminister))

**Merged pull requests:**

- Run tests on Python 3.9 [\#22](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/22) ([michaelarnauts](https://github.com/michaelarnauts))

## [v0.0.1](https://github.com/add-ons/plugin.video.tvvlaanderen/tree/v0.0.1) (2020-11-11)

[Full Changelog](https://github.com/add-ons/plugin.video.tvvlaanderen/compare/de15b078e0084d6bf2ae0a60af1dd902cc81fcd0...v0.0.1)

**Implemented enhancements:**

- Use CAPI for EPG so we have more data [\#18](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/18) ([michaelarnauts](https://github.com/michaelarnauts))
- Allow to install and run Kodi Logfile Uploader from the settings [\#17](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/17) ([michaelarnauts](https://github.com/michaelarnauts))
- Allow to install IPTV Manager from the settings [\#16](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/16) ([michaelarnauts](https://github.com/michaelarnauts))
- Implement IPTV Manager integration [\#11](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/11) ([michaelarnauts](https://github.com/michaelarnauts))
- Implement replay [\#10](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/10) ([michaelarnauts](https://github.com/michaelarnauts))
- Implement Restart & Replay [\#8](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/8) ([michaelarnauts](https://github.com/michaelarnauts))
- Update fanart [\#6](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/6) ([dagwieers](https://github.com/dagwieers))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*

==> plugin.video.tvvlaanderen-1.0.5.zip: plugin.video.tvvlaanderen/CHANGELOG.md <==
# Changelog

## [v1.0.5](https://github.com/add-ons/plugin.video.tvvlaanderen/tree/v1.0.5) (2022-01-22)

[Full Changelog](https://github.com/add-ons/plugin.video.tvvlaanderen/compare/v1.0.4...v1.0.5)

**Implemented enhancements:**

- Add support for Focus Sat in Romania [\#42](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/42) ([michaelarnauts](https://github.com/michaelarnauts))
- Add support for HD Austria [\#39](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/39) ([michaelarnauts](https://github.com/michaelarnauts))

**Fixed bugs:**

- Remove hardcoded CET timezone and fix timezone in IPTV Manager data [\#45](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/45) ([michaelarnauts](https://github.com/michaelarnauts))
- Fix adult settings for iptv-manager channel list [\#40](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/40) ([bananenfisch](https://github.com/bananenfisch))

**Merged pull requests:**

- HD Austria: language, readme, addon.xml, screenshots [\#48](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/48) ([bananenfisch](https://github.com/bananenfisch))
- Adding romanian translation [\#43](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/43) ([derzis](https://github.com/derzis))

## [v1.0.4](https://github.com/add-ons/plugin.video.tvvlaanderen/tree/v1.0.4) (2021-06-27)

[Full Changelog](https://github.com/add-ons/plugin.video.tvvlaanderen/compare/v1.0...v1.0.4)

**Fixed bugs:**

- Set a user-agent [\#34](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/34) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.0](https://github.com/add-ons/plugin.video.tvvlaanderen/tree/v1.0) (2021-06-27)

[Full Changelog](https://github.com/add-ons/plugin.video.tvvlaanderen/compare/v1.0.3...v1.0)

## [v1.0.3](https://github.com/add-ons/plugin.video.tvvlaanderen/tree/v1.0.3) (2021-02-04)

[Full Changelog](https://github.com/add-ons/plugin.video.tvvlaanderen/compare/v1.0.2...v1.0.3)

**Implemented enhancements:**

- Add http proxy support [\#30](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/30) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.0.2](https://github.com/add-ons/plugin.video.tvvlaanderen/tree/v1.0.2) (2020-12-21)

[Full Changelog](https://github.com/add-ons/plugin.video.tvvlaanderen/compare/v1.0.1...v1.0.2)

**Fixed bugs:**

- Don't show the password in the debug log [\#29](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/29) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.0.1](https://github.com/add-ons/plugin.video.tvvlaanderen/tree/v1.0.1) (2020-12-17)

[Full Changelog](https://github.com/add-ons/plugin.video.tvvlaanderen/compare/v1.0.0...v1.0.1)

**Fixed bugs:**

- Fix EPG on windows [\#28](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/28) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.0.0](https://github.com/add-ons/plugin.video.tvvlaanderen/tree/v1.0.0) (2020-12-05)

[Full Changelog](https://github.com/add-ons/plugin.video.tvvlaanderen/compare/v0.0.1...v1.0.0)

**Implemented enhancements:**

- Add PIN protection to 18+ channels [\#26](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/26) ([michaelarnauts](https://github.com/michaelarnauts))
- Add EPG to channel listing [\#24](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/24) ([michaelarnauts](https://github.com/michaelarnauts))
- Improve authentication flow [\#23](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/23) ([michaelarnauts](https://github.com/michaelarnauts))

**Fixed bugs:**

- Fix EPG in the channels view [\#25](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/25) ([michaelarnauts](https://github.com/michaelarnauts))
- Depend on inputstreamhelper to make sure widevine is installed [\#20](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/20) ([mediaminister](https://github.com/mediaminister))

## [v0.0.1](https://github.com/add-ons/plugin.video.tvvlaanderen/tree/v0.0.1) (2020-11-11)

[Full Changelog](https://github.com/add-ons/plugin.video.tvvlaanderen/compare/de15b078e0084d6bf2ae0a60af1dd902cc81fcd0...v0.0.1)

**Implemented enhancements:**

- Use CAPI for EPG so we have more data [\#18](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/18) ([michaelarnauts](https://github.com/michaelarnauts))
- Allow to install and run Kodi Logfile Uploader from the settings [\#17](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/17) ([michaelarnauts](https://github.com/michaelarnauts))
- Allow to install IPTV Manager from the settings [\#16](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/16) ([michaelarnauts](https://github.com/michaelarnauts))
- Implement IPTV Manager integration [\#11](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/11) ([michaelarnauts](https://github.com/michaelarnauts))
- Implement replay [\#10](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/10) ([michaelarnauts](https://github.com/michaelarnauts))
- Implement Restart & Replay [\#8](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/8) ([michaelarnauts](https://github.com/michaelarnauts))
- Update fanart [\#6](https://github.com/add-ons/plugin.video.tvvlaanderen/pull/6) ([dagwieers](https://github.com/dagwieers))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
